@@ -2,6 +2,6 @@
 from shellstream.shell import StreamingShell
 
 
-if __name__ == "__main__":
+def run():
     with StreamingShell() as shell:
         shell.stream()
